diff src/audacious/main.c @ 3543:6b8c8e051c1b trunk

Add new configuration option: Software Volume Control.
author William Pitcock <nenolod@atheme.org>
date Tue, 18 Sep 2007 10:12:20 -0500
parents 08dae20c75f0
children e82ad057d1db
line wrap: on
line diff
--- a/src/audacious/main.c	Mon Sep 17 22:43:19 2007 -0700
+++ b/src/audacious/main.c	Tue Sep 18 10:12:20 2007 -0500
@@ -224,7 +224,8 @@
     FALSE,          /* internal: whether or not to terminate */
     TRUE,           /* whether show progress bar in filepopup or not */
     TRUE,           /* close jtf dialog on jump */
-    TRUE,          /* use back and forth scroll */
+    TRUE,           /* use back and forth scroll */
+    FALSE,          /* use software volume control */
 };
 
 typedef struct bmp_cfg_boolent_t {
@@ -332,6 +333,7 @@
     {"filepopup_showprogressbar", &cfg.filepopup_showprogressbar, TRUE},
     {"close_jtf_dialog", &cfg.close_jtf_dialog, TRUE},
     {"twoway_scroll", &cfg.twoway_scroll, TRUE},
+    {"software_volume_control", &cfg.software_volume_control, TRUE},
 };
 
 static gint ncfgbent = G_N_ELEMENTS(bmp_boolents);